@@ -1,6 +1,6 @@
 # convert 5-year probability 
 # to 1-year probability
-prob_to_prob(p = .65, from = 5)
+rescale_prob(p = .65, from = 5)
 
 # convert 1-year probability 
 # to 1-month probability
