@@ -76,30 +76,6 @@ test_that(
       .6, .4
     )
     plot(mat1)
-    expect_error(
-      check_matrix(
-        matrix(
-          c(1, 0, 1, 1),
-          nrow = 2
-        )
-      )
-    )
-    expect_error(
-      check_matrix(
-        matrix(
-          c(1, 0, 1, 1),
-          nrow = 2
-        )
-      )
-    )
-    expect_error(
-      check_matrix(
-        matrix(
-          c(1, -1, 0, 2),
-          nrow = 2
-        )
-      )
-    )
     expect_equal(
       heemod:::get_matrix_order(mat1),
       2
@@ -108,6 +84,50 @@ test_that(
       get_state_names(mat1),
       c("X1", "X2")
     )
+    
+    test_array <- array(0, dim = c(2, 2, 2))
+    test_array[1,,] <- c(1, -1, 0, 2)
+    test_array[2,,] <- c(1, 0, 1, 1)
+    attr(test_array, "state_names") <- c("A", "B")
+    
+    expect_error(
+      check_matrix(test_array),
+      "rows sum to 1"
+    )
+    test_array[2,1, 2] <- 0
+    expect_error(
+      check_matrix(test_array),
+      "outside the interval [0 - 1]",
+      fixed = TRUE
+    )
+    
+    class(test_array) <- "not an array"
+    expect_error(
+      check_matrix(test_array),
+      'inherits(x, "array")',
+      fixed = TRUE
+    )
+    
+    ## test that we get expected error with expanded states
+    par1 <- define_parameters(a = ifelse(state_time == 3, 1.1, 0.5))
+    mat1 <- define_transition(a, C, 0.2, 0.8, state_names = c("A","B"))
+    
+    A1 <- define_state(cost = 1, utility = 1)
+    B1 <- define_state(cost = 2, utility = 2)
+    st1 <- define_strategy(A = A1, B = B1, transition = mat1)
+    
+    expect_error(run_model(
+      st1, init = c(100, 0), cycles = 5, parameters = par1
+    ),
+    "outside the interval [0 - 1]",
+    fixed = TRUE)
+    ## and that it works without the error
+    par1 <- define_parameters(a = ifelse(state_time == 3, 0.4, 0.5))
+    
+    expect_identical(
+      class(run_model(st1, init = c(100, 0), cycles = 5, parameters = par1,
+              cost = cost, effect = utility))[1],
+      "run_model")
   }
 )
 
@@ -130,10 +150,10 @@ test_that(
     e_par1 <- heemod:::eval_parameters(
       par1, 10
     )
-    e_mat <- heemod:::eval_matrix(
+    e_mat <- heemod:::eval_transition(
       mat1, e_par1
     )
-    e_matC <- heemod:::eval_matrix(
+    e_matC <- heemod:::eval_transition(
       matC, e_par1
     )
     expect_output(
@@ -189,7 +209,7 @@ test_that(
     sample_mod <- define_strategy(transition = sampleTM, A = A,
                                   B = B, C = C)
     res <- run_model(sample_mod, cost = cost, effect = utility,
-                      method = "beginning")
+                     method = "beginning")
     
     
     expect_equal(
