@@ -271,9 +271,16 @@ test_that(
       parameters = par1, cost = x, effect = y
     )
     
-    expect_output(
-      print(res),
-      "0            0    -"
+    expect_equal(
+      summary(res)$res_comp$.icer, c(NA, NaN)
+    )
+    
+    discount <- function(x, r) x
+    expect_warning(
+      run_model(
+        mod1, mod2,
+        parameters = par1, cost = x, effect = y
+      )
     )
   }
 )
\ No newline at end of file
